##  Pace Layering Using Tags
Tags offer the easiest way to model pace layering classification. Tags are helpful for categorizing Fact Sheets based on categories not covered by existing attributes or relationships.
To model pace layering with tags, start by creating a new tag group:
  1. Go to My settings by clicking on your profile at the top right corner.
  2. From under the Basic settings, click on Tagging to open the Tags section.
  3. Click the New Tag Group button at the top to create the new tag group.![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2749eadf7a4410148fb59923a6ba0bc1_LowRes.png)
  4. Fill in the fields such as Name and Description and select Business Capability from the Fact Sheet Type drop-down menu, as that is the Fact Sheet Type we are applying the tags to. Then click Add to create the group.![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27429c147a441014a54dad10376764c7_LowRes.gif)


Create new tags in the newly created tag group. We've named this "PACE Layering".
  1. Select the Tags tab From the PACE Layering tag group and click the Add Tag button.
  2. Create the three tags -- Commodity, Differentiation, and Innovation.
  3. Choose the color of the tags for easy differentiation. It is also a good practice to fill in the description so that the other users know what the tag means.![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27471d507a441014af289dbbbbdd1999_LowRes.gif)


Now, apply these tags to Business Capability Fact Sheets based on your organization’s situation and already completed classification assessment.
  1. Select the Business Capability Fact Sheet from the Inventory.
  2. Click Edit Tags at the top of the sheet.
  3. Select the right pace layering tag based on your classification.![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2741c0457a441014bc47ea6d6f8f8479_LowRes.gif)


Now, you can use various Reports to visualize the applied pace layering classifications. An excellent place to start is using the Business Capability Landscape Report.
  1. Select Business Capability Map in the Landscape Reports section.
  2. From the View dropdown, select the PACE Layering tag group, which was created earlier.![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2743a52a7a441014b77dbb178b591632_LowRes.gif)
